import { __decorate, __metadata } from 'tslib';
import { css, LitElement, html, property } from 'lit-element';
import '@a11y/focus-trap';
import { registerElementSafely } from 'lithiumjs/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles = css `
  .li-modal-wrapper {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 300;
  }

  .li-modal {
    border: 1px solid #ccc;
    padding: 12px;
    background-color: #fff;
    color: #2d2d2d;
    width: 500px;
    max-width: 100%;
    margin: 24px auto;
    position: relative;
    z-index: 302;
  }

  .li-modal-close-btn {
    position: absolute;
    text-align: center;
    width: auto;
    height: auto;
    padding: 12px;
    font-size: 24px;
    top: 0;
    right: 0;
    line-height: 14px;
    border: 0;
    background: transparent;
    cursor: pointer;
  }

  .li-modal-backdrop {
    background-color: rgba(0, 0, 0, 0.5);
    position: fixed;
    top: 0;
    bottom: 0;
    right: 0;
    left: 0;
    z-index: 301;
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumModal extends LitElement {
    constructor() {
        super(...arguments);
        this.open = false;
        this.backdropClosable = true;
    }
    /**
     * @return {?}
     */
    static get styles() {
        return styles;
    }
    /**
     * @return {?}
     */
    render() {
        return html `
      ${this.open
            ? html `
          <div class="li-modal-wrapper">
            <div class="li-modal" role="dialog">
              <focus-trap>
                <div class="li-modal-header">
                  <slot name="header"></slot>
                  <button @click="${(/**
             * @return {?}
             */
            () => this.close())}" type="button" aria-label="closed" class="li-modal-close-btn">&times;</button>
                </div>
                <div class="li-modal-content">
                  <slot></slot>
                </div>
                <div class="li-modal-footer">
                  <slot name="footer"></slot>
                </div>
              </focus-trap>
            </div>
            <div @click="${(/**
             * @return {?}
             */
            () => this.backdropClose())}" class="li-modal-backdrop"></div>
          </div>
          `
            : ''}
    `;
    }
    /**
     * @param {?} changedProperties
     * @return {?}
     */
    updated(changedProperties) {
        if (this.open && this.open !== changedProperties.get('open')) ;
    }
    /**
     * @return {?}
     */
    close() {
        this.open = !this.open;
        this.dispatchEvent(new CustomEvent('openChange', { detail: this.open }));
    }
    /**
     * @return {?}
     */
    backdropClose() {
        if (this.backdropClosable) {
            this.close();
        }
    }
}
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumModal.prototype, "open", void 0);
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumModal.prototype, "backdropClosable", void 0);
registerElementSafely('li-modal', LithiumModal);

export { LithiumModal };
//# sourceMappingURL=lithiumjs-modal.js.map
