import { __decorate, __metadata } from 'tslib';
import { css, LitElement, html, property } from 'lit-element';
import { registerElementSafely } from 'lithiumjs/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles = css `
  :host {
    --header-background-color: #f2f2f2;
    --header-text-color: #2d2d2d;
    --nav-top: 0;
    --nav-border-color: #f2f2f2;
    --nav-background-color: #fff;
    --nav-text-color: #2d2d2d;
    --nav-width: 280px;
    --transition-speed: 250ms;
  }

  .li-side-nav {
    position: fixed;
    left: -400px;
    top: var(--nav-top);
    bottom: 0;
    width: 80%;
    max-width: var(--nav-width);
    z-index: 201;
    background-color: var(--nav-background-color);
    overflow: hidden;
    will-change: left;
    transition: left var(--transition-speed) ease-in;
  }

  :host([sticky]) .li-side-nav {
    border-right: 1px solid var(--nav-border-color);
  }

  .li-side-nav-open .li-side-nav {
    left: 0;
  }

  .li-menu-heading {
    font-size: 18px;
    position: relative;
    height: 50px;
    overflow: hidden;
    background-color: var(--header-background-color);
    color: var(--header-text-color);
  }

  .li-menu-heading-text {
    float: left;
    padding: 14px 16px;
  }

  .li-menu-close-btn {
    border: 0;
    margin-bottom: 6px;
    padding: 10px 20px;
    height: 50px;
    display: block;
    position: absolute;
    font-size: 1.5em;
    right: 0;
    background-color: transparent;
    cursor: pointer;
    color: var(--header-text-color);
  }

  .li-side-nav-slot::slotted(a), .li-side-nav-slot::slotted(button) {
    display: block;
    padding: 18px 13px 16px 26px;
    font-size: 1em;
    text-decoration: none;
    color: var(--nav-text-color);
    position: relative;
    font-weight: bold;
    cursor: pointer;
  }

  .li-side-nav-backdrop {
    position: fixed;
    top: 0;
    left: 0;
    z-index: 200;
    width: 100%;
    height: 100%;
    background: transparent;
    pointer-events: none;
    will-change: background;
    transition: background var(--transition-speed) ease-in;
  }

  .li-side-nav-open .li-side-nav-backdrop {
    pointer-events: auto;
    background: rgba(0,0,0,.5);
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumSideNav extends LitElement {
    constructor() {
        super(...arguments);
        this.open = false;
        this.sticky = false;
        this.closeOnInnerClick = true;
    }
    /**
     * @return {?}
     */
    static get styles() {
        return styles;
    }
    /**
     * @return {?}
     */
    render() {
        return html `
      <div .classList=${this.sticky || this.open ? 'li-side-nav-open' : ''}>
        <nav class="li-side-nav">
          ${!this.sticky ? html `
            <div class="li-menu-heading">
              <div class="li-menu-heading-text"><slot name="heading">Menu</slot></div>
              <button aria-label="close menu" @click=${(/**
         * @param {?} e
         * @return {?}
         */
        e => this.close())} class="li-menu-close-btn">&times;</button>
            </div>
          ` : ''}
          <div @click=${(/**
         * @return {?}
         */
        () => this.navClose())}>
            <slot class="li-side-nav-slot"></slot>
          </div>
        </nav>
        ${!this.sticky ? html `<div @click=${(/**
         * @return {?}
         */
        () => this.close())} class="li-side-nav-backdrop"></div>` : ''}
      </div>
    `;
    }
    /**
     * @return {?}
     */
    close() {
        this.open = false;
        this.dispatchEvent(new CustomEvent('openChange', { detail: this.open }));
    }
    /**
     * @return {?}
     */
    navClose() {
        if (this.closeOnInnerClick && !this.sticky) {
            this.open = false;
            this.dispatchEvent(new CustomEvent('openChange', { detail: this.open }));
        }
    }
}
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumSideNav.prototype, "open", void 0);
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumSideNav.prototype, "sticky", void 0);
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumSideNav.prototype, "closeOnInnerClick", void 0);
registerElementSafely('li-side-nav', LithiumSideNav);

export { LithiumSideNav };
//# sourceMappingURL=lithiumjs-side-nav.js.map
