import { __decorate, __metadata } from 'tslib';
import { css, LitElement, html, property } from 'lit-element';
import { registerElementSafely } from 'lithiumjs/common';
import '@a11y/focus-trap';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles = css `
  .dropdown div {
    border: 1px solid #ccc;
    padding: 12px;
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class XDropdown extends LitElement {
    constructor() {
        super();
        this.visible = false;
        this.title = 'dropdown';
        this.visible = false;
        this.title = 'dropdown';
    }
    /**
     * @return {?}
     */
    static get styles() { return styles; }
    /**
     * @return {?}
     */
    render() {
        return html `
      <div class="dropdown">
        <button @click="${(/**
         * @return {?}
         */
        () => this.toggle())}" class="btn">${this.title}</button>
        ${this.visible ?
            html `
            <div>
              <slot></slot>
            </div>`
            : ''}
      </div>
    `;
    }
    /**
     * @return {?}
     */
    toggle() {
        this.visible = !this.visible;
        this.dispatchEvent(new CustomEvent('visibleChange', { detail: this.visible }));
    }
}
__decorate([
    property(),
    __metadata("design:type", Object)
], XDropdown.prototype, "visible", void 0);
__decorate([
    property(),
    __metadata("design:type", Object)
], XDropdown.prototype, "title", void 0);
registerElementSafely('x-dropdown', XDropdown);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles$1 = css `
  :host {
    --li-header-background-color: #f3f3f3;
    box-sizing: border-box;
    margin-bottom: 12px;
    background-color: var(--li-header-background-color);
    display: flex;
    width: 100%;
    overflow: hidden;
  }

  :host([sticky]) {
    position: fixed;
    z-index: 100;
  }

  ::slotted(a), ::slotted(button) {
    display: flex;
    align-items: center;
    height: 100%;
    padding: 12px;
  }

  ::slotted([li-nav-bar-right]) {
    margin-left: auto;
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumNavBar extends LitElement {
    /**
     * @return {?}
     */
    static get styles() { return styles$1; }
    /**
     * @return {?}
     */
    render() {
        return html `
      <slot></slot>
    `;
    }
}
registerElementSafely('li-nav-bar', LithiumNavBar);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles$2 = css `
  .li-modal-wrapper {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 300;
  }

  .li-modal {
    border: 1px solid #ccc;
    padding: 12px;
    background-color: #fff;
    color: #2d2d2d;
    width: 500px;
    max-width: 100%;
    margin: 24px auto;
    position: relative;
    z-index: 302;
  }

  .li-modal-close-btn {
    position: absolute;
    text-align: center;
    width: auto;
    height: auto;
    padding: 12px;
    font-size: 24px;
    top: 0;
    right: 0;
    line-height: 14px;
    border: 0;
    background: transparent;
    cursor: pointer;
  }

  .li-modal-backdrop {
    background-color: rgba(0, 0, 0, 0.5);
    position: fixed;
    top: 0;
    bottom: 0;
    right: 0;
    left: 0;
    z-index: 301;
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumModal extends LitElement {
    constructor() {
        super(...arguments);
        this.open = false;
        this.backdropClosable = true;
    }
    /**
     * @return {?}
     */
    static get styles() {
        return styles$2;
    }
    /**
     * @return {?}
     */
    render() {
        return html `
      ${this.open
            ? html `
          <div class="li-modal-wrapper">
            <div class="li-modal" role="dialog">
              <focus-trap>
                <div class="li-modal-header">
                  <slot name="header"></slot>
                  <button @click="${(/**
             * @return {?}
             */
            () => this.close())}" type="button" aria-label="closed" class="li-modal-close-btn">&times;</button>
                </div>
                <div class="li-modal-content">
                  <slot></slot>
                </div>
                <div class="li-modal-footer">
                  <slot name="footer"></slot>
                </div>
              </focus-trap>
            </div>
            <div @click="${(/**
             * @return {?}
             */
            () => this.backdropClose())}" class="li-modal-backdrop"></div>
          </div>
          `
            : ''}
    `;
    }
    /**
     * @param {?} changedProperties
     * @return {?}
     */
    updated(changedProperties) {
        if (this.open && this.open !== changedProperties.get('open')) ;
    }
    /**
     * @return {?}
     */
    close() {
        this.open = !this.open;
        this.dispatchEvent(new CustomEvent('openChange', { detail: this.open }));
    }
    /**
     * @return {?}
     */
    backdropClose() {
        if (this.backdropClosable) {
            this.close();
        }
    }
}
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumModal.prototype, "open", void 0);
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumModal.prototype, "backdropClosable", void 0);
registerElementSafely('li-modal', LithiumModal);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles$3 = css `
  :host {
    --header-background-color: #f2f2f2;
    --header-text-color: #2d2d2d;
    --nav-top: 0;
    --nav-border-color: #f2f2f2;
    --nav-background-color: #fff;
    --nav-text-color: #2d2d2d;
    --nav-width: 280px;
    --transition-speed: 250ms;
  }

  .li-side-nav {
    position: fixed;
    left: -400px;
    top: var(--nav-top);
    bottom: 0;
    width: 80%;
    max-width: var(--nav-width);
    z-index: 201;
    background-color: var(--nav-background-color);
    overflow: hidden;
    will-change: left;
    transition: left var(--transition-speed) ease-in;
  }

  :host([sticky]) .li-side-nav {
    border-right: 1px solid var(--nav-border-color);
  }

  .li-side-nav-open .li-side-nav {
    left: 0;
  }

  .li-menu-heading {
    font-size: 18px;
    position: relative;
    height: 50px;
    overflow: hidden;
    background-color: var(--header-background-color);
    color: var(--header-text-color);
  }

  .li-menu-heading-text {
    float: left;
    padding: 14px 16px;
  }

  .li-menu-close-btn {
    border: 0;
    margin-bottom: 6px;
    padding: 10px 20px;
    height: 50px;
    display: block;
    position: absolute;
    font-size: 1.5em;
    right: 0;
    background-color: transparent;
    cursor: pointer;
    color: var(--header-text-color);
  }

  .li-side-nav-slot::slotted(a), .li-side-nav-slot::slotted(button) {
    display: block;
    padding: 18px 13px 16px 26px;
    font-size: 1em;
    text-decoration: none;
    color: var(--nav-text-color);
    position: relative;
    font-weight: bold;
    cursor: pointer;
  }

  .li-side-nav-backdrop {
    position: fixed;
    top: 0;
    left: 0;
    z-index: 200;
    width: 100%;
    height: 100%;
    background: transparent;
    pointer-events: none;
    will-change: background;
    transition: background var(--transition-speed) ease-in;
  }

  .li-side-nav-open .li-side-nav-backdrop {
    pointer-events: auto;
    background: rgba(0,0,0,.5);
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumSideNav extends LitElement {
    constructor() {
        super(...arguments);
        this.open = false;
        this.sticky = false;
        this.closeOnInnerClick = true;
    }
    /**
     * @return {?}
     */
    static get styles() {
        return styles$3;
    }
    /**
     * @return {?}
     */
    render() {
        return html `
      <div .classList=${this.sticky || this.open ? 'li-side-nav-open' : ''}>
        <nav class="li-side-nav">
          ${!this.sticky ? html `
            <div class="li-menu-heading">
              <div class="li-menu-heading-text"><slot name="heading">Menu</slot></div>
              <button aria-label="close menu" @click=${(/**
         * @param {?} e
         * @return {?}
         */
        e => this.close())} class="li-menu-close-btn">&times;</button>
            </div>
          ` : ''}
          <div @click=${(/**
         * @return {?}
         */
        () => this.navClose())}>
            <slot class="li-side-nav-slot"></slot>
          </div>
        </nav>
        ${!this.sticky ? html `<div @click=${(/**
         * @return {?}
         */
        () => this.close())} class="li-side-nav-backdrop"></div>` : ''}
      </div>
    `;
    }
    /**
     * @return {?}
     */
    close() {
        this.open = false;
        this.dispatchEvent(new CustomEvent('openChange', { detail: this.open }));
    }
    /**
     * @return {?}
     */
    navClose() {
        if (this.closeOnInnerClick && !this.sticky) {
            this.open = false;
            this.dispatchEvent(new CustomEvent('openChange', { detail: this.open }));
        }
    }
}
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumSideNav.prototype, "open", void 0);
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumSideNav.prototype, "sticky", void 0);
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Object)
], LithiumSideNav.prototype, "closeOnInnerClick", void 0);
registerElementSafely('li-side-nav', LithiumSideNav);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles$4 = css `
  :host {
    --border-color: #ccc;
    --padding: 8px;
  }

  .li-tab__content {
    padding: var(--padding);
    overflow: visible;
    min-height: 225px;
    border-top: 1px solid var(--border-color);
  }

  @media (min-width: 480px) {
    .li-tab__content {
      padding: 18px;
    }
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumTab extends LitElement {
    constructor() {
        super(...arguments);
        this.title = '';
    }
    /**
     * @return {?}
     */
    static get styles() { return styles$4; }
    /**
     * @return {?}
     */
    render() {
        return html `
      <div class="li-tab__content">
        <slot></slot>
      </div>
    `;
    }
}
__decorate([
    property({ type: String }),
    __metadata("design:type", Object)
], LithiumTab.prototype, "title", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const styles$5 = css `
  :host {
    --color-primary: #2d2d2d;
    --border-color: #ccc;
    --tab-background-color: #fff;
    --breakpoint: 480px;
  }

  .li-tabs {
    display: block;
  }

  .li-tabs__nav {
    margin-bottom: 0;
    padding-left: 0;
    list-style: none;
  }

  .li-tabs__nav::before, .li-tabs__nav::after {
    content: ' ';
    display: table;
    clear: both;
  }

  .li-tabs__nav > button {
    position: relative;
    display: block;
    background-color: transparent;
    width: 50%;
    float: left;
    margin-bottom: -1px;
    cursor: pointer;
    padding: 10px 6px;
    line-height: 1.42857143;
    text-decoration: none;
    text-align: center;
    transition: all 0.3s;
    font-weight: 500;
    font-size: 14px;
  }

  .li-tabs__nav > button.active,
  .li-tabs__nav > button.active:hover,
  .li-tabs__nav > button.active:focus {
    cursor: default;
    color: var(--color-primary);
  }

  .li-tabs__nav > button:focus,
  .li-tabs__nav > button:hover {
    color: var(--color-primary);
  }

  .li-tabs__nav > button:nth-child(-n + 3) {
    border-bottom: 1px solid var(--border-color);
  }

  .li-tabs__nav > button:nth-child(even) {
    border-right: 1px solid var(--border-color);
  }

  @media (min-width: 300px) {
    .li-tabs__nav > button {
      margin-right: 2px;
      width: auto;
      text-align: left;
      border: 1px solid transparent;
      border-bottom: 3px solid transparent;
    }

    .li-tabs__nav > button:nth-child(even) {
      border-right: 0;
    }

    .li-tabs__nav > button:nth-child(-n + 3) {
      border-bottom: 3px solid transparent;
    }

    .li-tabs__nav > button.active {
      background-color: var(--tab-background-color);
      border: 1px solid var(--border-color);
      border-bottom: 3px solid transparent;
    }
  }

  @media (min-width: 480px) {
    .li-tabs__nav > button {
      padding: 10px 15px;
    }
  }
`;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class LithiumTabs extends LitElement {
    constructor() {
        super(...arguments);
        this.tabs = [];
        this.index = 0;
    }
    /**
     * @return {?}
     */
    static get styles() { return styles$5; }
    /**
     * @return {?}
     */
    render() {
        return html `
      <div class="li-tabs">
        <div class="li-tabs__nav">
          ${this.tabs.map((/**
         * @param {?} t
         * @param {?} i
         * @return {?}
         */
        (t, i) => html `
            <button className=${this.index === i ? 'active' : ''} @click=${(/**
         * @return {?}
         */
        () => this.tabClick(i))}>${t.title}</button>
          `))}
        </div>
        <slot></slot>
      </div>
    `;
    }
    /**
     * @return {?}
     */
    connectedCallback() {
        super.connectedCallback();
        this.tabs = [].slice.call(this.querySelectorAll('li-tab'));
        this.tabClick(0);
    }
    /**
     * @private
     * @param {?} index
     * @return {?}
     */
    tabClick(index) {
        this.index = index;
        this.showTab();
    }
    /**
     * @private
     * @return {?}
     */
    showTab() {
        this.tabs.forEach((/**
         * @param {?} t
         * @return {?}
         */
        t => t.style.display = 'none'));
        this.tabs[this.index].style.display = 'block';
    }
}
__decorate([
    property(),
    __metadata("design:type", Array)
], LithiumTabs.prototype, "tabs", void 0);
registerElementSafely('li-tab', LithiumTab);
registerElementSafely('li-tabs', LithiumTabs);

export { LithiumModal, LithiumNavBar, LithiumSideNav, LithiumTabs, XDropdown };
//# sourceMappingURL=lithiumjs.js.map
